@@ -1,5 +1,5 @@
 /*
- *  $Id: defLoad.c,v 4.5 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: defLoad.c,v 4.9 2006/01/24 23:22:16 bkorb Exp $
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition.
@@ -39,6 +39,40 @@ static tDefEntry*
 insertDef( tDefEntry* pDef );
 /* = = = END-STATIC-FORWARD = = = */
 
+#if defined(DEBUG_ENABLED)
+void
+manageAllocatedData( void* pd )
+{
+    static int    allocPtrCt   = 0;
+    static int    usedPtrCt    = 0;
+    static void** papAllocData = NULL;
+
+    if (pd == NULL) {
+        void** pp = papAllocData;
+        if (pp == NULL)
+            return;
+
+        while (--usedPtrCt >= 0)
+            AGFREE(*(pp++));
+
+        AGFREE(papAllocData);
+        papAllocData = NULL;
+
+    } else {
+        if (++usedPtrCt > allocPtrCt) {
+            allocPtrCt += 16;
+            papAllocData = (usedPtrCt > 1)
+                ? AGREALOC( papAllocData, allocPtrCt * sizeof(void*),
+                            "alloc table" )
+                : AGALOC( allocPtrCt * sizeof(void*), "new alloc table" );
+            if (papAllocData == NULL)
+                AG_ABEND( "failed alloc of papAllocData" );
+        }
+        papAllocData[usedPtrCt-1] = pd;
+    }
+}
+#endif
+
 LOCAL void
 freeEntry( tDefEntry* pDE )
 {
@@ -59,6 +93,8 @@ getEntry( void )
         int   ct = ENTRY_ALLOC_CT-1;
         void* p  = AGALOC( ENTRY_ALLOC_SIZE, "definition headers" );
 
+        manageAllocatedData(p);
+
         *((void**)p) = pAllocList;
         pAllocList   = p;
         pRes = pFreeEntryList = (tDefEntry*)((void**)p + 1);
@@ -155,23 +191,28 @@ insertDef( tDefEntry* pDef )
          *  We actually do this by leaving the pList pointer alone and swapping
          *  the contents of the definition entry.
          */
-        uDefValue val = pDef->val;
-        long      idx = pDef->index;
+        tDefEntry def = *pDef;
 
-        pDef->index   = pList->index;
-        pList->index  = idx;
-        pDef->val     = pList->val;
-        pList->val    = val;
+        memcpy( &(pDef->pzDefName), &(pList->pzDefName),
+                sizeof( def ) - ag_offsetof(tDefEntry, pzDefName) );
+
+        memcpy( &(pList->pzDefName), &(def.pzDefName),
+                sizeof( def ) - ag_offsetof(tDefEntry, pzDefName) );
 
         /*
-         *  Link the pDef in between pList and pList->pTwin
+         *  Contents are swapped.  Link "pDef" after "pList" and return "pList".
          */
-        pDef->pTwin   = pList->pTwin;
+        pDef->pTwin = pList->pTwin;
         if (pDef->pTwin != NULL)
             pDef->pTwin->pPrevTwin = pDef;
 
         pDef->pPrevTwin = pList;
         pList->pTwin  = pDef;
+
+        /*
+         *  IF this is the first twin, then the original list head is now
+         *  the "end twin".
+         */
         if (pList->pEndTwin == NULL)
             pList->pEndTwin = pDef;
 
@@ -218,7 +259,7 @@ findPlace( char* name, tCC* pzIndex )
         pE->index = strtol( pzIndex, NULL, 0 );
 
     else {
-        pzIndex = getDefine( pzIndex );
+        pzIndex = getDefine( pzIndex, AG_TRUE );
         if (pzIndex != NULL)
              pE->index = strtol( pzIndex, NULL, 0 );
         else pE->index = NO_INDEX;
@@ -239,6 +280,7 @@ findPlace( char* name, tCC* pzIndex )
 LOCAL void
 readDefines( void )
 {
+    tCC*     pzDefFile;
     char*    pzData;
     size_t   dataSize;
     size_t   sizeLeft;
@@ -250,17 +292,20 @@ readDefines( void )
         memset( (void*)pBaseCtx, 0, sizeof( tScanCtx ));
         pBaseCtx->lineNo     = 1;
         pBaseCtx->pzCtxFname = "@@ No-Definitions @@";
+        manageAllocatedData( pBaseCtx );
         return;
     }
 
+    pzDefFile = OPT_ARG( DEFINITIONS );
+
     /*
      *  Check for stdin as the input file.  We use the current time
      *  as the modification time for stdin.  We also note it so we
      *  do not try to open it and we try to allocate more memory if
      *  the stdin input exceeds our initial allocation of 16K.
      */
-    if (strcmp( OPT_ARG( DEFINITIONS ), "-" ) == 0) {
-        OPT_ARG( DEFINITIONS )  = "stdin";
+    if (strcmp( pzDefFile, "-" ) == 0) {
+        pzDefFile = OPT_ARG( DEFINITIONS ) = "stdin";
         if (getenv( "REQUEST_METHOD" ) != NULL) {
             loadCgi();
             pCurCtx = pBaseCtx;
@@ -280,14 +325,14 @@ readDefines( void )
     else {
         struct stat stbf;
 
-        if (stat( OPT_ARG( DEFINITIONS ), &stbf ) != 0)
-            AG_ABEND( aprf( zCannot, errno, "stat", OPT_ARG( DEFINITIONS ),
-                            strerror( errno )));
+        if (stat( pzDefFile, &stbf ) != 0)
+            AG_ABEND( aprf( zCannot, errno, "stat",
+                            pzDefFile, strerror( errno )));
 
         if (! S_ISREG( stbf.st_mode )) {
             errno = EINVAL;
             AG_ABEND( aprf( zCannot, errno, "open non-regular file",
-                            OPT_ARG( DEFINITIONS ), strerror( errno )));
+                            pzDefFile, strerror( errno )));
         }
 
         /*
@@ -328,11 +373,14 @@ readDefines( void )
     /*
      *  Set the input file pointer, as needed
      */
-    fp = useStdin ? stdin
-                  : fopen( OPT_ARG( DEFINITIONS ), "r" FOPEN_TEXT_FLAG );
-    if (fp == NULL)
-        AG_ABEND( aprf( zCannot, errno, "open", OPT_ARG( DEFINITIONS ),
-                        strerror( errno )));
+    if (useStdin)
+        fp = stdin;
+    else {
+        fp = fopen( pzDefFile, "r" FOPEN_TEXT_FLAG );
+        if (fp == NULL)
+            AG_ABEND( aprf( zCannot, errno, "open",
+                            pzDefFile, strerror( errno )));
+    }
 
     /*
      *  Read until done...
@@ -351,8 +399,8 @@ readDefines( void )
             if (feof( fp ) || useStdin)
                 break;
 
-            AG_ABEND( aprf( zCannot, errno, "read", OPT_ARG( DEFINITIONS ),
-                            strerror( errno )));
+            AG_ABEND( aprf( zCannot, errno, "read",
+                            pzDefFile, strerror( errno )));
         }
 
         /*
@@ -400,13 +448,15 @@ readDefines( void )
         AG_ABEND( "No definition data were read" );
 
     *pzData = NUL;
-    AGDUPSTR( pBaseCtx->pzCtxFname, OPT_ARG( DEFINITIONS ), "def file name" );
+    AGDUPSTR( pBaseCtx->pzCtxFname, pzDefFile, "def file name" );
+    manageAllocatedData( pBaseCtx );
+    manageAllocatedData( (void*)pBaseCtx->pzCtxFname );
 
     /*
      *  Close the input file, parse the data
      *  and alphabetically sort the definition tree contents.
      */
-    if (fp != stdin)
+    if (! useStdin)
         fclose( fp );
 
     pCurCtx = pBaseCtx;
@@ -414,9 +464,10 @@ readDefines( void )
 }
 
 
-void
+LOCAL void
 unloadDefs( void )
 {
+    return;
 }
 /*
  * Local Variables:
