@@ -1,7 +1,7 @@
 /*  -*- Mode: C -*-
  *
  *  expFormat.c
- *  $Id: expFormat.c,v 4.7 2005/12/04 22:26:21 bkorb Exp $
+ *  $Id: expFormat.c,v 4.9 2006/01/24 23:22:16 bkorb Exp $
  *  This module implements formatting expression functions.
  */
 
@@ -305,7 +305,7 @@ ag_scm_error( SCM res )
      */
     if (*pzMsg != NUL) {
         char* pz = aprf( zFmt, (abort != PROBLEM) ? zErr : zWarn,
-                         pCurTemplate->pzFileName, pCurMacro->lineNo,
+                         pCurTemplate->pzTplFile, pCurMacro->lineNo,
                          pCurFp->pzOutName, pzMsg );
         if (abort != PROBLEM)
             AG_ABEND( pz );
@@ -503,7 +503,6 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
     } lic = { NULL, { NULL, 0, 0, 0, 0, 0, 0, 0 }};
 
     char*     pzRes;
-    SCM       res;
 
     if (! AG_SCM_STRING_P( license ))
         return SCM_UNDEFINED;
