@@ -1,7 +1,7 @@
 
 /*
  *  expState.c
- *  $Id: expState.c,v 4.6 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: expState.c,v 4.9 2006/01/24 23:22:16 bkorb Exp $
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
  */
@@ -124,7 +124,7 @@ find_entry_value( SCM op, SCM obj, SCM test )
             return SCM_BOOL_F; /* Cannot match string -- not a text value */
         }
 
-        field  = gh_str02scm( pE->val.pzText );
+        field  = AG_SCM_STR02SCM( pE->val.pzText );
         result = gh_call2( op, field, test );
         if (! isIndexed)
             while (result == SCM_BOOL_F) {
@@ -133,7 +133,7 @@ find_entry_value( SCM op, SCM obj, SCM test )
                 if (pE == NULL)
                     break;
 
-                field = gh_str02scm( pE->val.pzText );
+                field = AG_SCM_STR02SCM( pE->val.pzText );
                 result = gh_call2( op, field, test );
             }
 
@@ -156,7 +156,7 @@ find_entry_value( SCM op, SCM obj, SCM test )
      */
     pzField[-1] = '.';
     {
-        SCM field   = gh_str02scm( pzField );
+        SCM field   = AG_SCM_STR02SCM( pzField );
         SCM result;
         tDefCtx ctx = currDefCtx;
 
@@ -195,7 +195,7 @@ find_entry_value( SCM op, SCM obj, SCM test )
 SCM
 ag_scm_base_name( void )
 {
-    return gh_str02scm( (char*)(void*)OPT_ARG( BASE_NAME ));
+    return AG_SCM_STR02SCM( (char*)(void*)OPT_ARG( BASE_NAME ));
 }
 
 
@@ -224,7 +224,7 @@ ag_scm_chdir( SCM dir )
         free( pCurDir );
     {
         char* pz = ag_scm2zchars( dir, zChdirDir );
-        pCurDir = malloc( SCM_LENGTH( dir ) + 1 );
+        pCurDir = malloc( AG_SCM_STRLEN( dir ) + 1 );
         strcpy( (char*)pCurDir, pz );
     }
     return dir;
@@ -248,7 +248,7 @@ ag_scm_count( SCM obj )
 {
     int ent_len = count_entries( ag_scm2zchars( obj, "ag object" ));
 
-    return gh_int2scm( ent_len );
+    return AG_SCM_INT2SCM( ent_len );
 }
 
 
@@ -263,7 +263,7 @@ ag_scm_count( SCM obj )
 SCM
 ag_scm_def_file( void )
 {
-    return gh_str02scm( (char*)(void*)pBaseCtx->pzCtxFname );
+    return AG_SCM_STR02SCM( (char*)(void*)pBaseCtx->pzCtxFname );
 }
 
 
@@ -346,8 +346,8 @@ ag_scm_ag_function_p( SCM obj )
 SCM
 ag_scm_match_value_p( SCM op, SCM obj, SCM test )
 {
-    if (  (! gh_procedure_p( op   ))
-       || (! gh_string_p(    obj  )) )
+    if (  (! AG_SCM_IS_PROC(  op  ))
+       || (! AG_SCM_STRING_P( obj )) )
         return SCM_UNDEFINED;
 
     if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
@@ -377,17 +377,17 @@ ag_scm_get( SCM agName, SCM altVal )
     tDefEntry*  pE;
     ag_bool     x;
 
-    if (! gh_string_p( agName ))
+    if (! AG_SCM_STRING_P( agName ))
          pE = NULL;
     else pE = findDefEntry( ag_scm2zchars( agName, "ag value" ), &x );
 
     if ((pE == NULL) || (pE->valType != VALTYP_TEXT)) {
-        if (gh_string_p( altVal ))
+        if (AG_SCM_STRING_P( altVal ))
             return altVal;
-        return gh_str02scm( "" );
+        return AG_SCM_STR02SCM( "" );
     }
 
-    return gh_str02scm( pE->val.pzText );
+    return AG_SCM_STR02SCM( pE->val.pzText );
 }
 
 
@@ -425,15 +425,15 @@ ag_scm_high_lim( SCM obj )
      *  ELSE search the twin list for the high entry
      */
     if (pE == NULL)
-        return gh_int2scm( 0 );
+        return AG_SCM_INT2SCM( 0 );
 
     if (isIndexed)
-        return gh_int2scm( pE->index );
+        return AG_SCM_INT2SCM( pE->index );
 
     if (pE->pEndTwin != NULL)
         pE = pE->pEndTwin;
 
-    return gh_int2scm( pE->index );
+    return AG_SCM_INT2SCM( pE->index );
 }
 
 
@@ -456,7 +456,7 @@ ag_scm_len( SCM obj )
 
     len = entry_length( ag_scm2zchars( obj, "ag value" ));
 
-    return gh_int2scm( len );
+    return AG_SCM_INT2SCM( len );
 }
 
 
@@ -482,9 +482,9 @@ ag_scm_low_lim( SCM obj )
      *  ELSE we have the low index.
      */
     if (pE == NULL)
-        return gh_int2scm( 0 );
+        return AG_SCM_INT2SCM( 0 );
 
-    return gh_int2scm( pE->index );
+    return AG_SCM_INT2SCM( pE->index );
 }
 
 
@@ -515,7 +515,7 @@ ag_scm_set_option( SCM opt )
 SCM
 ag_scm_suffix( void )
 {
-    return gh_str02scm( (char*)pzCurSfx );
+    return AG_SCM_STR02SCM( (char*)pzCurSfx );
 }
 
 
@@ -533,14 +533,14 @@ ag_scm_suffix( void )
 SCM
 ag_scm_tpl_file( SCM full )
 {
-    if (gh_boolean_p( full ) && SCM_NFALSEP( full )) {
+    if (AG_SCM_BOOL_P( full ) && SCM_NFALSEP( full )) {
         tSCC* sfx[] = { "tpl", NULL };
         char z[MAXPATHLEN];
         if (SUCCESSFUL( findFile( pzTemplFileName, z, sfx )))
-            return gh_str02scm( z );
+            return AG_SCM_STR02SCM( z );
     }
 
-    return gh_str02scm( (char*)(void*)pzTemplFileName );
+    return AG_SCM_STR02SCM( (char*)(void*)pzTemplFileName );
 }
 
 
@@ -573,11 +573,11 @@ ag_scm_tpl_file_line( SCM fmt )
     tCC*    pzFmt = zFmt;
     char*   pz;
 
-    if (gh_string_p( fmt ))
+    if (AG_SCM_STRING_P( fmt ))
         pzFmt = ag_scm2zchars( fmt, "file/line format" );
 
     {
-        size_t  maxlen = strlen( pCurTemplate->pzFileName )
+        size_t  maxlen = strlen( pCurTemplate->pzTplFile )
                        + strlen( pzFmt ) + 4 * sizeof( int );
         if (maxlen >= sizeof( zScribble ))
             pz = (char*)AGALOC( maxlen, "file-line buffer" );
@@ -586,13 +586,13 @@ ag_scm_tpl_file_line( SCM fmt )
 
     {
         void* args[2];
-        args[0] = (void*)pCurTemplate->pzFileName;
+        args[0] = (void*)pCurTemplate->pzTplFile;
         args[1] = (void*)(long)pCurMacro->lineNo;
         sprintfv( pz, pzFmt, (snv_constpointer*)args  );
     }
 
     {
-        SCM res = gh_str02scm( pz );
+        SCM res = AG_SCM_STR02SCM( pz );
         if (pz != zScribble)
             AGFREE( (void*)pz );
 
@@ -644,7 +644,7 @@ ag_scm_def_file_line( SCM obj, SCM fmt )
     if (pE == NULL)
         return SCM_UNDEFINED;
 
-    if (gh_string_p( fmt ))
+    if (AG_SCM_STRING_P( fmt ))
         pzFmt = ag_scm2zchars( fmt, "file/line format" );
 
     {
@@ -662,7 +662,7 @@ ag_scm_def_file_line( SCM obj, SCM fmt )
     }
 
     {
-        SCM res = gh_str02scm( pzScrib );
+        SCM res = AG_SCM_STR02SCM( pzScrib );
         if (pzScrib != zScribble)
             AGFREE( (void*)pzScrib );
 
