@@ -1,6 +1,6 @@
 
 /*
- *  $Id: funcFor.c,v 4.4 2005/03/13 19:51:32 bkorb Exp $
+ *  $Id: funcFor.c,v 4.9 2006/01/24 23:22:16 bkorb Exp $
  *
  *  This module implements the FOR text macro.
  */
@@ -21,8 +21,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 #define ENTRY_END  INT_MAX
@@ -69,7 +69,7 @@ ag_scm_first_for_p( SCM which )
     if (forInfo.fi_depth <= 0)
         return SCM_UNDEFINED;
 
-    if (! gh_string_p( which ))
+    if (! AG_SCM_STRING_P( which ))
         return (pFS->for_firstFor) ? SCM_BOOL_T : SCM_BOOL_F;
 
     {
@@ -106,7 +106,7 @@ ag_scm_last_for_p( SCM which )
     if (forInfo.fi_depth <= 0)
         return SCM_UNDEFINED;
 
-    if (! gh_string_p( which ))
+    if (! AG_SCM_STRING_P( which ))
         return (pFS->for_lastFor ? SCM_BOOL_T : SCM_BOOL_F);
 
     {
@@ -143,8 +143,8 @@ ag_scm_for_index( SCM which )
     if (forInfo.fi_depth <= 0)
         return SCM_UNDEFINED;
 
-    if (! gh_string_p( which ))
-        return gh_int2scm( pFS->for_index );
+    if (! AG_SCM_STRING_P( which ))
+        return AG_SCM_INT2SCM( pFS->for_index );
 
     {
         tForState* p   = forInfo.fi_data + (forInfo.fi_depth - 1);
@@ -154,7 +154,7 @@ ag_scm_for_index( SCM which )
 
         do  {
             if (strcmp( p->for_pzName, pz ) == 0) {
-                res = gh_int2scm( p->for_index );
+                res = AG_SCM_INT2SCM( p->for_index );
                 break;
             }
             p--;
@@ -178,9 +178,9 @@ ag_scm_for_index( SCM which )
 SCM
 ag_scm_for_from( SCM from )
 {
-    if ((! pFS->for_loading) || (! gh_number_p( from )))
+    if ((! pFS->for_loading) || (! AG_SCM_NUM_P( from )))
         return SCM_UNDEFINED;
-    pFS->for_from = gh_scm2int( from );
+    pFS->for_from = AG_SCM_SCM2INT( from );
     return SCM_BOOL_T;
 }
 
@@ -198,9 +198,9 @@ ag_scm_for_from( SCM from )
 SCM
 ag_scm_for_to( SCM to )
 {
-    if ((! pFS->for_loading) || (! gh_number_p( to )))
+    if ((! pFS->for_loading) || (! AG_SCM_NUM_P( to )))
         return SCM_UNDEFINED;
-    pFS->for_to = gh_scm2int( to );
+    pFS->for_to = AG_SCM_SCM2INT( to );
     return SCM_BOOL_T;
 }
 
@@ -218,9 +218,9 @@ ag_scm_for_to( SCM to )
 SCM
 ag_scm_for_by( SCM by )
 {
-    if ((! pFS->for_loading) || (! gh_number_p( by )))
+    if ((! pFS->for_loading) || (! AG_SCM_NUM_P( by )))
         return SCM_UNDEFINED;
-    pFS->for_by = gh_scm2int( by );
+    pFS->for_by = AG_SCM_SCM2INT( by );
     return SCM_BOOL_T;
 }
 
@@ -306,7 +306,7 @@ doForByStep( tTemplate* pT,
 {
     int         loopCt    = 0;
     tDefEntry   textDef;
-    ag_bool     invert    = (pFS->for_by < 0);
+    ag_bool     invert    = (pFS->for_by < 0) ? AG_TRUE : AG_FALSE;
     t_word      loopLimit = OPT_VALUE_LOOP_LIMIT;
     tDefCtx     ctx       = currDefCtx;
 
@@ -411,8 +411,8 @@ doForByStep( tTemplate* pT,
         }
 
         pFS->for_lastFor = (invert)
-            ? (nextIdx < pFS->for_to)
-            : (nextIdx > pFS->for_to);
+            ? ((nextIdx < pFS->for_to) ? AG_TRUE : AG_FALSE)
+            : ((nextIdx > pFS->for_to) ? AG_TRUE : AG_FALSE);
 
         generateBlock( pT, pMac+1, pT->aMacros + pMac->endIndex );
         loopCt++;
@@ -517,6 +517,7 @@ load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
         pz = AGALOC( srcLen + 2 + nmlen, "copy of FOR x IN ... text" );
         strcpy( pz, pzName );
         pzName = pz;
+        manageAllocatedData(pz);
         pz += nmlen + 1;
     }
 
@@ -599,6 +600,7 @@ load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
  *  cindex:  looping, for
  *  cindex:  for loop
  *  handler_proc:
+ *  load_proc:
  *
  *  desc:
  *  This macro has a slight variation on the standard syntax:
@@ -674,6 +676,7 @@ load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
 /*=macfunc ENDFOR
  *
  *  what:   Terminates the @code{FOR} function template block
+ *  in-context:
  *
  *  desc:
  *    This macro ends the @code{FOR} function template block.
@@ -697,7 +700,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
                          pT->pzTemplText + pMac->ozName );
 
                 if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
-                    fprintf( pfTrace, zFileLine, pT->pzFileName, pMac->lineNo );
+                    fprintf( pfTrace, zFileLine, pT->pzTplFile, pMac->lineNo );
             }
 
             return pMRet;
@@ -722,7 +725,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
 
     if (OPT_VALUE_TRACE >= TRACE_BLOCK_MACROS)
         fprintf( pfTrace, "FOR %s loop in %s on line %d begins:\n",
-                 pT->pzTemplText + pMac->ozName, pT->pzFileName,
+                 pT->pzTemplText + pMac->ozName, pT->pzTplFile,
                  pMac->lineNo );
 
     if (pT->pzTemplText[ pMac->ozText ] == '(') {
@@ -746,7 +749,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
                  pT->pzTemplText + pMac->ozName, loopCt );
 
         if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
-            fprintf( pfTrace, zFileLine, pT->pzFileName, pMac->lineNo );
+            fprintf( pfTrace, zFileLine, pT->pzTplFile, pMac->lineNo );
     }
 
     return pMRet;
