@@ -1,12 +1,12 @@
 
 /*
- *  $Id: functions.c,v 1.40 2004/02/02 03:31:50 bkorb Exp $
+ *  $Id: functions.c,v 4.6 2006/01/24 23:22:17 bkorb Exp $
  *
  *  This module implements text functions.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -21,18 +21,18 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 tSCC zCantInc[] = "cannot include file";
 tSCC zTrcFmt[] = "%-10s (%2X) in %s at line %d\n";
 
-
 /*=macfunc INCLUDE
  *
  *  what:   Read in and emit a template block
  *  handler_proc:
+ *  load_proc:
  *
  *  desc:
  *
@@ -76,9 +76,9 @@ mFunc_Include( tTemplate* pT, tMacro* pMac )
         if (OPT_VALUE_TRACE > TRACE_NOTHING) {
             tSCC zTplFmt[] = "Template %s included\n";
             tSCC zLinFmt[] = "\tfrom %s line %d\n";
-            fprintf( pfTrace, zTplFmt, pNewTpl->pzFileName );
+            fprintf( pfTrace, zTplFmt, pNewTpl->pzTplFile );
             if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
-                fprintf( pfTrace, zLinFmt, pCurTemplate->pzFileName,
+                fprintf( pfTrace, zLinFmt, pCurTemplate->pzTplFile,
                          pMac->lineNo );
         }
 
@@ -114,6 +114,7 @@ mLoad_Include( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  *
  *  what:  Either a user macro or a value name.
  *  handler_proc:
+ *  load_proc:
  *  unnamed:
  *
  *  desc:
@@ -131,8 +132,8 @@ mFunc_Unknown( tTemplate* pT, tMacro* pMac )
     tTemplate* pInv = findTemplate( pT->pzTemplText + pMac->ozName );
     if (pInv != NULL) {
         if (OPT_VALUE_TRACE >= TRACE_EVERYTHING)
-            fprintf( pfTrace, zTrcFmt, "remapped to Define", pMac->funcCode,
-                     pT->pzFileName, pMac->lineNo );
+            fprintf( pfTrace, zTrcFmt, "remapped to 'Invoke'", pMac->funcCode,
+                     pT->pzTplFile, pMac->lineNo );
         pMac->funcCode    = FTYP_DEFINE;
         pMac->funcPrivate = (void*)pInv;
         parseMacroArgs( pT, pMac );
@@ -141,7 +142,7 @@ mFunc_Unknown( tTemplate* pT, tMacro* pMac )
 
     if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
         fprintf( pfTrace, zTrcFmt, "remapped to Expr", pMac->funcCode,
-                 pT->pzFileName, pMac->lineNo );
+                 pT->pzTplFile, pMac->lineNo );
         fprintf( pfTrace, "\tbased on %s\n", pT->pzTemplText + pMac->ozName );
     }
 
@@ -183,6 +184,7 @@ mFunc_Unknown( tTemplate* pT, tMacro* pMac )
  *
  *  what:  Out-of-context or unknown functions are bogus.
  *  handler_proc:
+ *  load_proc:
  *  unnamed:
 =*/
 tMacro*
@@ -215,6 +217,8 @@ mFunc_Text( tTemplate* pT, tMacro* pMac )
 /*=macfunc COMMENT
  *
  *  what:  A block of comment to be ignored
+ *  load_proc:
+ *  alias: "#"
  *
  *  desc:
  *    This function can be specified by the user, but there will
@@ -367,7 +371,7 @@ mLoad_Bogus( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         pzMac = apzFuncNames[ ix ];
     }
 
-    pzSrc = aprf( zUnk, pT->pzFileName, pMac->lineNo, pzMac, pzSrc );
+    pzSrc = aprf( zUnk, pT->pzTplFile, pMac->lineNo, pzMac, pzSrc );
 
     AG_ABEND_IN( pT, pMac, pzSrc );
     /* NOTREACHED */
