@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Thu Dec 15 15:11:44 PST 2005
+ * Generated Fri Feb  3 08:01:18 PST 2006
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD
@@ -116,6 +116,9 @@ findPlace( char* name, tCC* pzIndex );
 LOCAL void
 readDefines( void );
 
+LOCAL void
+unloadDefs( void );
+
 /*
  *  Extracted from expGuile.c
  */
@@ -173,12 +176,15 @@ findTemplate( tCC* pzTemplName );
 LOCAL tSuccess
 findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList );
 
-LOCAL tTemplate*
-templateFixup( tTemplate* pTList, size_t ttlSize );
-
 LOCAL tTemplate*
 loadTemplate( tCC* pzFileName );
 
+LOCAL void
+unloadTemplate( tTemplate* pT );
+
+LOCAL void
+cleanup( tTemplate* pTF );
+
 /*
  *  Extracted from tpParse.c
  */
