@@ -1,12 +1,12 @@
 
 /*
  *  agTempl.c
- *  $Id: tpProcess.c,v 1.31 2003/05/24 02:40:43 bkorb Exp $
+ *  $Id: tpProcess.c,v 4.6 2006/01/24 23:22:17 bkorb Exp $
  *  Parse and process the template data descriptions
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -21,21 +21,27 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
-STATIC void openOutFile( tOutSpec* pOutSpec, tFpStack* pStk );
+static tFpStack fpRoot = { 0, NULL, NULL, NULL };
 
-STATIC tFpStack fpRoot = { 0, NULL, NULL, NULL };
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+doStdoutTemplate( tTemplate* pTF );
 
+static void
+openOutFile( tOutSpec* pOutSpec, tFpStack* pStk );
+/* = = = END-STATIC-FORWARD = = = */
 
 /*
  *  Generate all the text within a block.  The caller must
  *  know the exact bounds of the block.  "pEnd" actually
  *  must point to the first entry that is *not* to be emitted.
  */
-EXPORT void
+LOCAL void
 generateBlock( tTemplate*   pT,
                tMacro*      pMac,
                tMacro*      pEnd )
@@ -58,7 +64,7 @@ generateBlock( tTemplate*   pT,
         if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
 
             fprintf( pfTrace, zFmt, apzFuncNames[ fc ], pMac->funcCode,
-                     pT->pzFileName, pMac->lineNo );
+                     pT->pzTplFile, pMac->lineNo );
             if (pMac->ozText > 0) {
                 int   ct;
                 char* pz = pT->pzTemplText + pMac->ozText;
@@ -77,14 +83,15 @@ generateBlock( tTemplate*   pT,
 
         pCurMacro = pMac;
         pMac = (*(apHdlrProc[ fc ]))( pT, pMac );
+        ag_scmStrings_free();
     }
 }
 
 
-STATIC void
+static void
 doStdoutTemplate( tTemplate* pTF )
 {
-    tSCC zNone[]  = "* NONE *";
+    tSCC zNoSfx[] = "* NONE *";
     tSCC zBadR[]  = "%sBogus return from setjmp:  %d\n";
     int  jmpcode  = setjmp( fileAbort );
     SCM  res;
@@ -116,7 +123,7 @@ doStdoutTemplate( tTemplate* pTF )
         exit( EXIT_FAILURE );
     }
 
-    pzCurSfx      = zNone;
+    pzCurSfx      = zNoSfx;
     currDefCtx    = rootDefCtx;
     pCurFp        = &fpRoot;
     fpRoot.pFile  = stdout;
@@ -144,26 +151,26 @@ doStdoutTemplate( tTemplate* pTF )
          *  a content-type: prefix.  If not, we supply our own HTML prefix.
          */
         res   = ag_scm_out_pop( SCM_BOOL_T );
-        pzRes = SCM_CHARS( res );
+        pzRes = AG_SCM_CHARS( res );
 
         if (strneqvcmp( pzRes, zCont, sizeof( zCont ) - 1) != 0)
             fputs( "Content-Type: text/html\n\n", stdout );
 
-        fwrite( pzRes, SCM_LENGTH( res ), 1, stdout );
+        fwrite( pzRes, AG_SCM_STRLEN( res ), 1, stdout );
     }
 
     fclose( stdout );
 }
 
 
-EXPORT void
+LOCAL void
 processTemplate( tTemplate* pTF )
 {
     forInfo.fi_depth = 0;
 
     /*
      *  IF the template file does not specify any output suffixes,
-     *  THEN we will generate to standard out with the suffix set to zNone.
+     *  THEN we will generate to standard out with the suffix set to zNoSfx.
      *  With output going to stdout, we don't try to remove output on errors.
      */
     if (pOutSpecList == NULL) {
@@ -242,7 +249,7 @@ processTemplate( tTemplate* pTF )
 }
 
 
-EXPORT void
+LOCAL void
 closeOutput( ag_bool purge )
 {
     if ((pCurFp->flags & FPF_NOCHMOD) == 0)
@@ -288,10 +295,10 @@ closeOutput( ag_bool purge )
 }
 
 
-STATIC void
+static void
 openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
 {
-    char*  pzDefFile;
+    tCC*  pzDefFile;
 
     /*
      *  Figure out what to use as the base name of the output file.
@@ -304,24 +311,28 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
      *  Remove any suffixes in the last file name
      */
     {
-        char*  p = strrchr( pzDefFile, '/' );
-        if (p == NULL)
-            p = pzDefFile;
+        char   z[ MAXPATHLEN ];
+        tCC*   pS = strrchr( pzDefFile, '/' );
+        char*  pE;
+        if (pS == NULL)
+            pS = pzDefFile;
+
+        pE = strchr( pS, '.' );
+        if (pE != NULL) {
+            memcpy( z, pS, pE - pS );
+            z[ pE - pS ] = NUL;
+            pS = z;
+        }
 
-        p = strchr( p, '.' );
-        if (p != NULL)
-            *p = NUL;
         /*
          *  Now formulate the output file name in the buffer
          *  provided as the input argument.
          */
-        pStk->pzOutName = aprf( pOutSpec->pzFileFmt, pzDefFile,
+        pStk->pzOutName = aprf( pOutSpec->pzFileFmt, pS,
                                 pOutSpec->zSuffix );
         if (pStk->pzOutName == NULL)
             AG_ABEND( aprf( "Cannot format file name:  ``%s''",
                             pOutSpec->pzFileFmt ));
-        if (p != NULL)
-            *p = '.';
     }
 
     pCurFp = pStk;
@@ -332,7 +343,7 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
          *  Make the output a no-op, but perform the operations.
          */
         AGFREE( (void*)pStk->pzOutName );
-        pStk->pzOutName = (char*)zDevNull;
+        pStk->pzOutName = zDevNull;
         pStk->flags    |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
         pStk->pFile     = fopen( zDevNull, "w" FOPEN_BINARY_FLAG "+" );
         if (pStk->pFile != NULL)
@@ -348,7 +359,7 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
      */
     if (HAVE_OPT( SKIP_SUFFIX )) {
         int     ct  = STACKCT_OPT(  SKIP_SUFFIX );
-        char**  ppz = STACKLST_OPT( SKIP_SUFFIX );
+        tCC**   ppz = STACKLST_OPT( SKIP_SUFFIX );
 
         while (--ct >= 0) {
             if (strcmp( pOutSpec->zSuffix, *ppz++ ) == 0)
