@@ -1,6 +1,7 @@
 
 /*
- *  $Id: autoopts.c,v 4.5 2005/02/04 04:24:45 bkorb Exp $
+ *  $Id: autoopts.c,v 4.13 2005/11/07 00:22:04 bkorb Exp $
+ *  Time-stamp:      "2005-10-29 13:19:36 bkorb"
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -24,8 +25,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with Automated Options.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  *
  * As a special exception, Bruce Korb gives permission for additional
  * uses of the text contained in his release of AutoOpts.
@@ -55,6 +56,16 @@
 #  include "compat/pathfind.c"
 #endif
 
+#ifndef HAVE_LIBSNPRINTFV
+# ifndef HAVE_SNPRINTF
+#   include "compat/snprintf.c"
+# endif
+
+# ifndef HAVE_STRDUP
+#   include "compat/strdup.c"
+# endif
+#endif
+
 static const char zNil[] = "";
 
 #define SKIP_RC_FILES(po) \
@@ -149,7 +160,7 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
              */
             p->optActualValue = pOD->optValue;
             p->optActualIndex = pOD->optIndex;
-            pOptState->flags |= OPTST_EQUIVALENCE;          
+            pOptState->flags |= OPTST_EQUIVALENCE;
         }
 
         /*
@@ -339,7 +350,7 @@ longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState )
  *  Find the short option descriptor for the current option
  */
 LOCAL tSuccess
-shortOptionFind( tOptions* pOpts, tUC optValue, tOptState* pOptState )
+shortOptionFind( tOptions* pOpts, tAoUC optValue, tOptState* pOptState )
 {
     tOptDesc*  pRes = pOpts->pOptDesc;
     int        ct   = pOpts->optCt;
@@ -500,6 +511,7 @@ static tSuccess
 nextOption( tOptions* pOpts, tOptState* pOptState )
 {
     tSuccess res;
+    enum { ARG_NONE, ARG_MAY, ARG_MUST } arg_type = ARG_NONE;
 
     res = findOptDesc( pOpts, pOptState );
     if (! SUCCESSFUL( res ))
@@ -513,10 +525,15 @@ nextOption( tOptions* pOpts, tOptState* pOptState )
      *  Disabled mode option selection also disables option arguments.
      */
     if ((pOptState->flags & OPTST_DISABLED) != 0)
-         pOptState->argType = ARG_NONE;
-    else pOptState->argType = pOptState->pOD->optArgType;
+        arg_type = ARG_NONE;
+    else if (OPTST_GET_ARGTYPE(pOptState->flags) == OPARG_TYPE_NONE)
+        arg_type = ARG_NONE;
+    else if (pOptState->flags & OPTST_ARG_OPTIONAL)
+        arg_type = ARG_MAY;
+    else
+        arg_type = ARG_MUST;
 
-    switch (pOptState->argType) {
+    switch (arg_type) {
     case ARG_MUST:
         /*
          *  An option argument is required.  Long options can either have
@@ -688,7 +705,7 @@ doImmediateOpts( tOptions* pOpts )
      *  are marked for immediate processing.
      */
     for (;;) {
-        tOptState optState = OPTSTATE_INITIALIZER;
+        tOptState optState = OPTSTATE_INITIALIZER(PRESET);
 
         switch (nextOption( pOpts, &optState )) {
         case FAILURE: goto optionsDone;
@@ -721,7 +738,7 @@ doRegularOpts( tOptions* pOpts )
      *  non-standard programs that require it.)
      */
     for (;;) {
-        tOptState optState = OPTSTATE_INITIALIZER;
+        tOptState optState = OPTSTATE_INITIALIZER(DEFINED);
 
         switch (nextOption( pOpts, &optState )) {
         case FAILURE: goto optionsDone;
@@ -771,8 +788,7 @@ doPresets( tOptions* pOpts )
     }
     else {
         doEnvPresets( pOpts, ENV_IMM );
-        if (configFileLoad( pOpts, NULL ) < 0)
-            return FAILURE;
+        internalFileLoad( pOpts );
         doEnvPresets( pOpts, ENV_NON_IMM );
     }
     pOpts->fOptSet &= ~OPTPROC_PRESETTING;
@@ -836,23 +852,23 @@ checkConsistency( tOptions* pOpts )
         /*
          *  IF       this option is not equivalenced to another,
          *        OR it is equivalenced to itself (is the equiv. root)
-         *  THEN we need to make sure it occurrs often enough.
+         *  THEN we need to make sure it occurs often enough.
          */
         if (  (pOD->optEquivIndex == NO_EQUIVALENT)
            || (pOD->optEquivIndex == pOD->optIndex) )   do {
             /*
-             *  IF the occurrance counts have been satisfied,
+             *  IF the occurrence counts have been satisfied,
              *  THEN there is no problem.
              */
             if (pOD->optOccCt >= pOD->optMinCt)
                 break;
 
             /*
-             *  IF presetting is okay and it has been preset,
-             *  THEN min occurrance count doesn't count
+             *  IF MUST_SET means SET and PRESET are okay,
+             *  so min occurrence count doesn't count
              */
-#           define PRESET_OK  (OPTST_PRESET | OPTST_MUST_SET)
-            if ((pOD->fOptState & PRESET_OK) == PRESET_OK)
+            if (  (pOD->fOptState & OPTST_MUST_SET)
+               && (pOD->fOptState & (OPTST_PRESET | OPTST_SET)) )
                 break;
 
             errCt++;
@@ -936,10 +952,13 @@ checkConsistency( tOptions* pOpts )
  * do not want to do this.
  *
  * The number of arguments processed always includes the program name.
- * If one of the arguments is "--", then it is counted and the
- * processing stops.  If an error was encountered and errors are
- * to be tolerated, then the returned value is the index of the
- * argument causing the error.
+ * If one of the arguments is "--", then it is counted and the processing
+ * stops.  If an error was encountered and errors are to be tolerated, then
+ * the returned value is the index of the argument causing the error.
+ * A hyphen by itself ("-") will also cause processing to stop and will
+ * @emph{not} be counted among the processed arguments.  A hyphen by itself
+ * is treated as an operand.  Encountering an operand stops option
+ * processing.
  *
  * err:  Errors will cause diagnostics to be printed.  @code{exit(3)} may
  *       or may not be called.  It depends upon whether or not the options
@@ -1020,6 +1039,5 @@ optionProcess(
  * c-file-style: "stroustrup"
  * tab-width: 4
  * indent-tabs-mode: nil
- * tab-width: 4
  * End:
  * end of autoopts/autoopts.c */
