@@ -1,5 +1,6 @@
 
-/*  $Id: version.c,v 4.3 2005/01/24 00:00:37 bkorb Exp $
+/*  $Id: version.c,v 4.6 2005/12/13 20:07:29 bkorb Exp $
+ * Time-stamp:      "2005-12-13 10:29:09 bkorb"
  *
  *  This module implements the default usage procedure for
  *  Automated Options.  It may be overridden, of course.
@@ -21,8 +22,8 @@ static const char zAOV[] =
  *  You should have received a copy of the GNU General Public License
  *  along with Automated Options.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  *
  * As a special exception, Bruce Korb gives permission for additional
  * uses of the text contained in his release of AutoOpts.
@@ -82,10 +83,14 @@ printVersion( tOptions* pOpts, tOptDesc* pOD, FILE* fp )
          swCh = 'v';
     else swCh = pOD->pzLastArg[0];
 
-    if (pOpts->pzFullVersion != NULL)
-         fputs( pOpts->pzFullVersion, fp );
-    else fputs( pOpts->pzProgName,    fp );
-    fputc( '\n', fp );
+    if (pOpts->pzFullVersion != NULL) {
+        fputs( pOpts->pzFullVersion, fp );
+        fputc( '\n', fp );
+
+    } else {
+        const char *pz = pOpts->pzUsageTitle;
+        do { fputc( *pz, fp ); } while (*(pz++) != '\n');
+    }
 
     switch (swCh) {
     case NUL:
@@ -130,7 +135,7 @@ printVersion( tOptions* pOpts, tOptDesc* pOD, FILE* fp )
     exit( EXIT_SUCCESS );
 }
 
-/*=export_func  doVersion
+/*=export_func  optionPrintVersion
  * private:
  *
  * what:  Print the program version
@@ -141,14 +146,14 @@ printVersion( tOptions* pOpts, tOptDesc* pOD, FILE* fp )
  *  This routine will print the version to stdout.
 =*/
 void
-doVersion( pOpts, pOD )
+optionPrintVersion( pOpts, pOD )
     tOptions*  pOpts;
     tOptDesc*  pOD;
 {
     printVersion( pOpts, pOD, stdout );
 }
 
-/*=export_func  doVersionStderr
+/*=export_func  optionVersionStderr
  * private:
  *
  * what:  Print the program version to stderr
@@ -159,7 +164,7 @@ doVersion( pOpts, pOD )
  *  This routine will print the version to stderr.
 =*/
 void
-doVersionStderr( pOpts, pOD )
+optionVersionStderr( pOpts, pOD )
     tOptions*  pOpts;
     tOptDesc*  pOD;
 {
